@@ -17,7 +17,8 @@ our %EXPORT_TAGS = (
 		   syscall_resolve_name
 		   syscall_resolve_name_arch
 		   syscall_resolve_name_rewrite
-		   syscall_resolve_num_arch/ ],
+		   syscall_resolve_num_arch
+		   version/ ],
 
 	macros => [
 		qw/SCMP_ACT_ALLOW
@@ -172,7 +173,7 @@ our %EXPORT_TAGS = (
 		   __NR_query_module
 		   __NR_readdir
 		   __NR_readlink
-s		   __NR_recv
+		   __NR_recv
 		   __NR_recvfrom
 		   __NR_recvmmsg
 		   __NR_recvmsg
@@ -466,7 +467,7 @@ our @EXPORT = @{$EXPORT_TAGS{macros}};
 
 our $VERSION;
 BEGIN{
-	$VERSION = '0.001';
+	$VERSION = '0.002';
 }
 
 sub AUTOLOAD {
@@ -587,7 +588,7 @@ Most methods die on error.
 
 =over
 
-=item I<$ctx> = Linux::Seccomp->B<new>(I<$def_action>>)
+=item I<$ctx> = Linux::Seccomp->B<new>(I<$def_action>)
 
 Creates a new C<Linux::Seccomp> filter, with the default action for
 unhandled syscalls being I<$def_action>. Possible values for
@@ -649,43 +650,57 @@ we are comparing. I<$op> is as follows:
 =over
 
 =item SCMP_CMP_NE
+
 =item '!='
+
 =item 'ne'
 
 Matches when the argument value is not equal to I<$datum_a>.
 
 =item SCMP_CMP_LT
+
 =item '<'
+
 =item 'lt'
 
 Matches when the argument value is less than I<$datum_a>.
 
 =item SCMP_CMP_LE
+
 =item '<='
+
 =item 'le'
 
 Matches when the argument value is less than or equal to I<$datum_a>.
 
 =item SCMP_CMP_EQ
+
 =item '=='
+
 =item 'eq'
 
 Matches when the argument value is equal to I<$datum_a>.
 
 =item SCMP_CMP_GE
+
 =item '>='
+
 =item 'ge'
 
 Matches when the argument value is greater than or equal to I<$datum_a>.
 
 =item SCMP_CMP_GT
+
 =item '>'
+
 =item 'gt'
 
 Matches when the argument value is greater than I<$datum_a>.
 
 =item SCMP_CMP_MASKED_EQ
+
 =item '=~'
+
 =item 'me'
 
 Matches when the argument value masked with I<$datum_a> is equal to I<$datum_b> masked with I<$datum_a>.
@@ -704,12 +719,12 @@ See L<seccomp_arch_add(3)>.
 
 Returns true if the given architecture is in the filter, false
 otherwise.
-See L<seccomp_arch_add(3).
+See L<seccomp_arch_add(3)>.
 
 =item I<$ctx>->B<arch_remove>(I<$arch_token>)
 
 Removes an architecture from the filter.
-See L<seccomp_arch_add(3).
+See L<seccomp_arch_add(3)>.
 
 =item I<$ctx>->B<attr_get>(I<$attr>)
 
